Annot class

An annotation object.

Constructors

Annot(String? id, int? pageNumber)
Annot.fromJson(dynamic json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
An annotation has its id in XFDF as name.
getter/setter pair
pageNumber ↔ int?
Page numbers are 1-indexed here, but 0-indexed in XFDF strings.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited