AnnotFlag class

A flag object for an annotation.

Constructors

AnnotFlag(String? flag, bool? flagValue)

Properties

flag ↔ String?
One of the AnnotationFlags constants.
getter/setter pair
flagValue ↔ bool?
Represents toggling the flag on or off.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited