AnnotProperty class

An annotation property object.

Some of this object's properties are markup annotation exclusive, some are not.

Constructors

AnnotProperty()

Properties

contentRect ↔ Rect?
Markup exclusive.
getter/setter pair
contents ↔ String?
Not markup exclusive.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
rect ↔ Rect?
Not markup exclusive.
getter/setter pair
rotation ↔ int?
Not markup exclusive.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject ↔ String?
Markup exclusive.
getter/setter pair
title ↔ String?
Markup exclusive.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited