AnnotWithRect class

An annotation associated with its rectangle.

Constructors

AnnotWithRect(String? id, int? pageNumber, Rect? rect)
AnnotWithRect.fromJson(dynamic json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
pageNumber ↔ int?
getter/setter pair
rect ↔ Rect?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited