Config class

A class to contain the viewer configuration options.

The class properties represent all possible viewer configuration options. These options are not required and have default values.

Constructors

Config()
Config.fromJson(Map<String, dynamic> json)

Properties

annotationAuthor ← String
The author name for all annotations created on the current document.
no getter
annotationManagerEditMode ← String
The annotation manager's edit mode when annotationManagerEnabled is true and userId is not null.
no getter
annotationManagerEnabled ← bool
Defines whether the annotation manager is enabled.
no getter
annotationManagerUndoMode ← String
The annotation manager's undo mode when annotationManagerEnabled is true and userId is not null.
no getter
annotationMenuItems ← List
A list of AnnotationMenuItems that will show when an annotation is selected.
no getter
annotationPermissionCheckEnabled ← bool
Whether the annotation's flags will be considered upon its selection.
no getter
annotationsListEditingEnabled ← bool
Whether the annotation list is editable if document editing is enabled.
no getter
annotationsListFilterEnabled ← bool
Whether filtering the annotation list is possible.
no getter
annotationToolbarAlignment ← String
The alignment of the annotation toolbars.
no getter
annotationToolbars ← List
A list of CustomToolbar objects or DefaultToolbars constants that define a set of annotation toolbars.
no getter
autoResizeFreeTextEnabled ← bool
Whether to automatically resize the bounding box of free text annotations when editing.
no getter
autoSaveEnabled ← bool
Whether the document is automatically saved.
no getter
base64FileExtension ← String
The file extension to use when isBase64String is true.
no getter
bottomToolbar ← List
A list of Buttons that will appear in the bottom toolbar.
no getter
continuousAnnotationEditing ← bool
Whether the active annotation creation tool will remain the current annotation tool.
no getter
customHeaders ← Map<String, String>
A map containing custom headers to use with HTTP/HTTPS requests.
no getter
defaultEraserType ← String
The default eraser tool type.
no getter
disabledElements ← List
A list of Buttons that will be disabled in the viewer.
no getter
disabledTools ← List
A list of Tools that will be disabled in the viewer.
no getter
disableEditingByAnnotationType ← List
A list of Tools that cannot be edited after creation.
no getter
documentSliderEnabled ← bool
Whether the document slider of the viewer is enabled.
no getter
downloadDialogEnabled ← bool
Whether the download dialog should be shown.
no getter
excludedAnnotationListTypes ← List
A list of Tools that will be excluded from the annotation list.
no getter
exportPath ← String
The folder path where the file will be saved for actions to save a copy of the document.
no getter
fitMode ← String
The default zoom level of the viewer.
no getter
followSystemDarkMode ← bool
Whether the UI will appear in a dark color when the system is in dark mode.
no getter
fullScreenModeEnabled ← bool
Whether to enable the viewer's full screen mode.
no getter
hashCode → int
The hash code for this object.
no setterinherited
hideAnnotationMenu ← List
A list of Tools that will not show in the default annotation menu.
no getter
hideAnnotationToolbarSwitcher ← bool
Whether to show the toolbar switcher in the top toolbar.
no getter
hideBottomToolbar ← bool
Whether to hide the bottom toolbar for the current viewer.
no getter
hideDefaultAnnotationToolbars ← List
A list of DefaultToolbars that will be hidden.
no getter
hidePresetBar ← bool
Whether to hide the preset bar for the current viewer.
no getter
hideScrollbars ← bool
Whether scroll bars will be hidden in the viewer.
no getter
hideThumbnailFilterModes ← List
A list of ThumbnailFilterModes that will be hidden in the thumbnails browser.
no getter
hideToolbarsOnTap ← bool
Whether an unhandled tap in the viewer should toggle the visibility of the top and bottom toolbars.
no getter
hideTopAppNavBar ← bool
Whether to hide the top app navigation bar.
no getter
hideTopToolbars ← bool
Whether to hide the top app navigation bar and the annotation toolbar.
no getter
hideViewModeItems ← List
The view mode items to be hidden in the view mode dialog.
no getter
imageInReflowModeEnabled ← bool
Whether to show images in reflow mode.
no getter
initialPageNumber ← int
The initial page number upon opening a document.
no getter
initialToolbar ← String
The annotation toolbar that will be selected when the document is opened.
no getter
isBase64String ← bool
Whether to treat the document being opened as a base64 string.
no getter
layoutMode ← String
The layout mode of the viewer.
no getter
longPressMenuEnabled ← bool
Whether to show a popup menu after the user long presses on text or blank space.
no getter
longPressMenuItems ← List
A list of LongPressMenuItems that will be shown after a long press on text or blank space.
no getter
maxSignatureCount ← int
The maximum number of saved signatures that can be created for a document.
no getter
maxTabCount ← int
The maximum number of tabs that the viewer could have at a time.
no getter
multiTabEnabled ← bool
Whether the viewer will use tabs to enable having multiple documents open simultaneously.
no getter
openSavedCopyInNewTab ← bool
Whether newly saved files should open in a new tab after saving.
no getter
openUrlPath ← String
The folder path where cache files are saved when opening files from HTTPS.
no getter
outlineListEditingEnabled ← bool
Whether the outline list is editable.
no getter
overrideAnnotationMenuBehavior ← List
A list of AnnotationMenuItems that will skip default behavior when pressed.
no getter
overrideBehavior ← List<String>
A list of Behaviors that will skip their default behavior.
no getter
overrideLongPressMenuBehavior ← List
A list of LongPressMenuItems that will skip default behavior when pressed.
no getter
pageChangeOnTap ← bool
Whether the viewer should change pages when the user taps the edge of a page if the viewer is in a horizontal viewing mode.
no getter
pageIndicatorEnabled ← bool
Whehter to show the page indicator in the viewer.
no getter
pageNumberIndicatorAlwaysVisible ← bool
Whether the page indicator is always visible.
no getter
quickBookmarkCreation ← bool
Whether a bookmark creation button will be included in the bottom toolbar.
no getter
readOnly ← bool
Whether the viewer will allow users to edit the document.
no getter
reflowOrientation ← String
The scrolling direction of the reflow control.
no getter
rememberLastUsedTool ← bool
Whether the last tool used in the current viewer session will be the tool selected upon starting a new viewer session.
no getter
restrictDownloadUsage ← bool
Whether to restrict data usage when viewing online PDFs.
no getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectAnnotationAfterCreation ← bool
Whether annotations are selected after creation.
no getter
showDocumentSavedToast ← bool
Whether a toast indicating that the document has been successfully or unsuccessfully saved will appear.
no getter
showLeadingNavButton ← bool
Whether to show the leading navigation button.
no getter
showNavigationListAsSidePanelOnLargeDevices ← bool
Whether the navigation list will be displayed as a side panel on large devices such as iPads and tablets.
no getter
showQuickNavigationButton ← bool
Whether the quick navigation buttons will appear in the viewer.
no getter
showSavedSignatures ← bool
Whether to enable saving multiple signatures for re-use.
no getter
signatureColors ← List
A list of colors that the user can select to create a signature.
no getter
signatureDrawingEnabled ← bool
Whether to enable drawing to create a new signature.
no getter
signaturePhotoPickerEnabled ← bool
Whether to show the option to select images in the signature dialog.
no getter
signatureTypingEnabled ← bool
Whether to enable typing to create a new signature.
no getter
signSignatureFieldWithStamps ← bool
Whether signature fields will be signed with image stamps.
no getter
singleLineToolbar ← bool
Whether to use a single-line toolbar instead of a double-line toolbar.
no getter
tabletLayoutEnabled ← bool
Whether the tablet layout should be used on tablets.
no getter
tabTitle ← String
The tab title if multiTabEnabled is true.
no getter
thumbnailViewEditingEnabled ← bool
Whether the user can edit the document from the thumbnail view.
no getter
topAppNavBarRightBar ← List
A list of Buttons and CustomToolbarItems that will appear in the right bar section of the top app navigation bar.
no getter
userBookmarksListEditingEnabled ← bool
Whether the bookmark list is editable.
no getter
userId ← String
The unique identifier of the current user.
no getter
userName ← String
The name of the current user.
no getter
useStylusAsPen ← bool
Whether a stylus should act like a pen when the viewer is in pan mode.
no getter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited