CustomToolbarItem class

A custom toolbar item.

Custom toolbar items can be included in a custom toolbar by adding the object to the CustomToolbar.items list. Android only.

Constructors

CustomToolbarItem(String? id, String? name, String? icon)

Properties

hashCode → int
The hash code for this object.
no setterinherited
icon ↔ String?
Name of the image resource to be used as the item's icon.
getter/setter pair
id ↔ String?
Unique identifier of the toolbar item.
getter/setter pair
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited