PdftronFlutter class

A native plugin for viewing documents and accessing features of the PDFTron SDK.

Constructors

PdftronFlutter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setHorizontalScrollPosition(int horizontalScrollPosition) → Future<void>
Sets the horizontal scroll position in the current document viewer.
setVerticalScrollPosition(int verticalScrollPosition) → Future<void>
Sets the vertical scroll position in the current document viewer.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

platformVersion → Future<String>
The current version of the OS that the app is running on.
no setter
version → Future<String>
The current version of the PDFTron SDK.
no setter

Static Methods

addBookmark(String title, int pageNumber) → Future<void>
Creates a new bookmark with the given title and page number.
canRedo() → Future<bool?>
Checks whether a redo operation can be perfromed from the current snapshot.
canUndo() → Future<bool?>
Checks whether an undo operation can be performed from the current snapshot.
closeAllTabs() → Future<void>
Closes all documents that are currently open in a multi-tab environment.
commitTool() → Future<bool?>
Commits the current tool.
deleteAllAnnotations() → Future<void>
Deletes all annotations in the current document, excluding links and widgets.
deleteAnnotations(List<Annot> annotationList) → Future<void>
Deletes the specified annotations in the current document.
exitSearchMode() → Future<void>
Exits the search mode.
exportAnnotations(List<Annot>? annotationList) → Future<String?>
Exports the specified annotations in the current document as a XFDF annotation string.
exportAsImage(int? pageNumber, int? dpi, String? exportFormat) → Future<String?>
Exports the specified page to an image format defined by exportFormat.
exportAsImageFromFilePath(int? pageNumber, int? dpi, String? exportFormat, String? filePath) → Future<String?>
Exports the specified page to an image format defined by exportFormat.
flattenAnnotations(bool formsOnly) → Future<void>
Flattens the forms and (optionally) annotations in the current document.
getAnnotationsOnPage(int pageNumber) → Future<List<Annot>?>
Gets the list of annotations on the given page.
getCurrentPage() → Future<int?>
Gets the current page of the document.
getDocumentPath() → Future<String?>
Returns the path of the current document.
getPageCount() → Future<int?>
Gets the total number of pages in the currently displayed document.
getPageCropBox(int pageNumber) → Future<Rect>
Gets a Rect object of the crop box for the specified page.
getPageRotation(int pageNumber) → Future<int>
Gets the rotation value of the specified page in the current document.
getSavedSignatureFolder() → Future<String?>
Gets the absolute path to the folder containing all saved signatures as PDFs.
getSavedSignatureJpgFolder() → Future<String?>
Gets the absolute path to the folder containing all saved signatures as JPGs.
getSavedSignatures() → Future<List<String>?>
Gets a list of absolute file paths to all saved signatures as PDFs.
getScrollPos() → Future<Map?>
Gets the horizontal and vertical scroll position in the current document viewer.
getVisiblePages() → Future<List<int>?>
Gets the page numbers of currently visible pages in the viewer.
getZoom() → Future<double?>
Returns the current zoom scale of the current document viewer.
gotoFirstPage() → Future<bool?>
Goes to the first page of the document.
gotoLastPage() → Future<bool?>
Goes to the last page of the document.
gotoNextPage() → Future<bool?>
Goes to the next page of the document.
gotoPreviousPage() → Future<bool?>
Goes to the previous page of the document.
groupAnnotations(Annot primaryAnnotation, List<Annot>? subAnnotations) → Future<void>
Groups the specified annotations in the current document.
handleBackButton() → Future<bool?>
Handles the back button in search mode.
importAnnotationCommand(String xfdfCommand) → Future<void>
Imports remote annotation command to the local document.
importAnnotations(String xfdf) → Future<void>
Imports the given XFDF annotation string to the current document.
importBookmarkJson(String bookmarkJson) → Future<void>
Imports user bookmarks into the document.
initialize([String licenseKey = ""]) → Future<void>
Initializes the PDFTron SDK using a license key.
mergeAnnotations(String xfdf) → Future<void>
Merges the given XFDF annotation string to the current document.
openAddPagesView(Map<String, double>? sourceRect) → Future<void>
Displays the Add Pages view.
openAnnotationList() → Future<void>
Displays the Annotation tab of the existing list container.
openBookmarkList() → Future<void>
Displays the Bookmark tab of the existing list container.
openCrop() → Future<void>
Displays the Page Crop Options dialog.
openDocument(String document, {String? password, Config? config}) → Future<void>
Opens a document in the viewer with configurations.
openGoToPageView() → Future<void>
Opens a go-to page dialog.
openLayersList() → Future<void>
Displays the Layers dialog on Android, or the Layers tab of the existing list container on iOS.
openManualCrop() → Future<void>
Displays the Manual Page Crop dialog.
openNavigationLists() → Future<void>
Displays the existing list container.
openOutlineList() → Future<void>
Displays the Outline tab of the existing list container.
openRotateDialog() → Future<void>
Displays the Rotate dialog.
openSearch() → Future<void>
Displays a search bar that allows the user to enter and search text within a document.
openTabSwitcher() → Future<void>
Opens the tab switcher in a multi-tab environment.
openThumbnailsView() → Future<void>
Displays the Thumbnails view.
openViewSettings(Map<String, double>? sourceRect) → Future<void>
Displays the view settings.
redo() → Future<void>
Redoes the last modification.
rotateClockwise() → Future<void>
Rotates all pages in the current document in a clockwise direction by 90 degrees.
rotateCounterClockwise() → Future<void>
Rotates all pages in the current document in a counter-clockwise direction by 90 degrees.
saveDocument() → Future<String?>
Saves the current document and returns the absolute path to the file.
selectAnnotation(Annot annotation) → Future<void>
Selects the specified annotation in the current document.
setBackgroundColor(int red, int green, int blue) → Future<void>
Sets the background color of the viewer.
setCurrentPage(int pageNumber) → Future<bool?>
Sets the current page of the document to the given page number.
setDefaultPageColor(int red, int green, int blue) → Future<void>
Sets the default page color of the viewer.
setFitMode(String fitMode) → Future<void>
Sets the page view mode in the viewer
setFlagForFields(List<String> fieldNames, int flag, bool flagValue) → Future<void>
Sets the value of the given flag to flagValue on the given form fields.
setFlagsForAnnotations(List<AnnotWithFlag> annotationWithFlagsList) → Future<void>
Sets flags for the specified annotations in the current document.
setLayoutMode(String layoutMode) → Future<void>
Sets the page presentation mode in the viewer
setLeadingNavButtonIcon(String path) → Future<void>
Sets the icon of the leading navigation button.
setPropertiesForAnnotation(Annot annotation, AnnotProperty property) → Future<void>
Sets properties for the specified annotation in the current document.
setRequestedOrientation(int requestedOrientation) → Future<void>
Changes the orientation of this activity.
setToolMode(String toolMode) → Future<void>
Sets the current tool mode.
setValuesForFields(List<Field> fields) → Future<void>
Sets the field value of the given form fields.
setZoomLimits(String mode, double minimum, double maximum) → Future<void>
Sets the minimum and maximum zoom bounds of the current viewer.
smartZoom(int x, int y, bool animated) → Future<void>
Zooms to a paragraph that contains the specified coordinate.
startSearchMode(String searchString, bool matchCase, bool matchWholeWord) → Future<void>
Starts the search mode.
undo() → Future<void>
Undoes the last modification.
ungroupAnnotations(List<Annot>? annotations) → Future<void>
Ungroups the specified annotations in the current document.
zoomToRect(int pageNumber, Map<String, double> rect) → Future<void>
Zooms the viewer to fit the given rectangular area in the specified page.
zoomWithCenter(double zoom, int x, int y) → Future<void>
Zooms the viewer to the given scale using the given coordinate as the center.