Rect class

A rect object for the viewer.

Constructors

Rect(double? x1, double? y1, double? x2, double? y2, double? width, double? height)
Rect.fromCoordinates(double? x1, double? y1, double? x2, double? y2)
Rect.fromJson(dynamic json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
height ↔ double?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ double?
getter/setter pair
x1 ↔ double?
getter/setter pair
x2 ↔ double?
getter/setter pair
y1 ↔ double?
getter/setter pair
y2 ↔ double?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getDouble(dynamic value) → dynamic
A helper for JSON number decoding.